from distutils.core import setup

setup(
    name='django-da_login',
    version='0.1',
    packages=['da_login'],
    url='',
    license='',
    author='hramik',
    author_email='hramik@gmail.com',
    description='Register/Login app for Django'
)
